##################################################################
###   Load required packages and source file                   ###
##################################################################
library(data.table)
library(ca)
library(beeswarm)
library(ggtern)
library(raster)
library(mapplots)
library(maptools)
library(Bchron)
library(plyr)

source("Code/EF_OQ_source.R")

##################################################################
###   Read in zooarch data and grouping/coding information     ###
##################################################################

# Main data (using file.path to avoid platform-dependency)
sites <- fread(file.path("working_data", "zoo_summary_sites.csv"))
phases <- fread(file.path("working_data", "zoo_summary_phase.csv"))
taxon <- fread(file.path("working_data", "zoo_summary_taxon.csv"))
EN.dates <- fread(file.path("working_data", "continental_EN_14C.csv"))

# Taxon/grouping info
taxa <- fread(file.path("working_data", "taxa.csv"))
grouping <- fread(file.path("working_data", "grouping_table.csv"))

# Colour codes
col.codes <- fread(file.path("working_data", "RGB colours.csv"))
cols <- rgb(col.codes$red, col.codes$green, col.codes$blue, col.codes$alpha, names=col.codes$Region, maxColorValue = 255)

# Label directions
lab.nudge <- fread(file.path("working_data", "label_nudges.csv"))

##################################################################
###   Read in GIS datasets                                     ###
##################################################################

# Topographical data
if (!file.exists("topo")) {
    dir.create(file.path(getwd(), "topo"))
    lon.list = c(13, 13, 19, 19, 23, 23)
    lat.list = c(46, 42, 46, 42, 46, 42)
    for(i in 1:length(lon.list)) {
        getData("SRTM", lon=lon.list[i], lat=lat.list[i], path=file.path(getwd(), "topo"))
    }
}

# Merge topo tiles into single object
topo.data <- list()
tifs <- grep("tif", dir("topo"))
for(i in 1:length(tifs)) {
    topo.data[i] <- raster(file.path(getwd(), "topo", dir("topo")[tifs[i]]))
}
topo.data$fun <- mean
map.data <- do.call(mosaic, topo.data)

# Administrative boundary data
if (!file.exists("gadm")) {dir.create(file.path(getwd(), "gadm"))}
state.list = c("Serbia", "Kosovo", "Italy", "Slovenia", "Croatia", "Hungary", "Bosnia and Herzegovina", "Montenegro", "Albania", "Greece", "Bulgaria", "Romania", "MKD")
gadm.list <- list()
for(i in 1:length(state.list)) {
    gadm.list[i] <- getData("GADM", country=state.list[i], level=0, path=file.path(getwd(), "gadm"))
}

# Download and unzip rivers dataset
if (!file.exists("water")) {dir.create(file.path(getwd(), "water"))}
river.files <- c("ne_10m_rivers_europe", "ne_10m_rivers_lake_centerlines",
                 "ne_10m_lakes_europe", "ne_10m_lakes")
river.path <- file.path(getwd(), "water", paste(river.files, ".zip", sep=""))
rivers <- list()
for(i in 1:length(river.path)) {
      if (!file.exists(river.path[i])) {
            download.file(paste("http//www.naturalearthdata.com/download/10m/physical/", river.path[i], sep=""), river.path[i])
      }
      unzip(river.path[i], exdir=file.path(getwd(), "water"))
}

rivers <- readShapeLines(file.path(getwd(), "water", paste(river.files[1], ".shp", sep=""))) +
      readShapeLines(file.path(getwd(), "water", paste(river.files[2], ".shp", sep="")))
lakes <- readShapePoly(file.path(getwd(), "water", paste(river.files[3], ".shp", sep=""))) +
      readShapePoly(file.path(getwd(), "water", paste(river.files[4], ".shp", sep="")))

##################################################################
###   Prepare zooarchaeological data for analysis              ###
##################################################################

# Select taxa to use
taxa <- merge(taxa, grouping, by="TAXON", all=TRUE)
taxa <- taxa[is.na(TAXON_GROUP), TAXON_GROUP:=TAXON]
taxa <- taxa[CLASS=="Mammalia" & NISP.COUNT==1,] 
taxa <- taxa[!ORDER=="Cetacea" & !TAXON=="alcealc" & !TAXON=="damadam" & !TAXON=="talpeur"]
taxa <- taxa[!ORDER=="Rodentia" | GENUS=="Castor"]
taxon <- merge(taxon, taxa, by="TAXON", all=FALSE)

# Exclude assemblages that can't be narrowed down to our periods
phases <- phases[!is.na(PERIOD)]

# Merge dataset together
data <- merge(sites, phases[,list(PHASE, SITE_CODE, PERIOD, RECOVERY, FULL_LIST, FULL_DOMS, FULL_COUNT, CITATION)], by="SITE_CODE", all=FALSE)
data <- merge(data, taxon, by="PHASE", all=FALSE)
data <- data[is.na(PRESENCE_ONLY),]
data <- data[, ZONE := as.factor(ZONE)]
data <- data[, REGION := as.factor(REGION)]
data <- data[, TYPE := as.factor(TYPE)]
data <- data[, RECOVERY := as.factor(RECOVERY)]
data <- data[TAXON_GROUP=="equuspe", WILD_DOMESTIC_STATUS:="wild"] # Make assumption that no domestic equids present

# Lump data into three main phases
lump.list <- c("SITE", "TAXON", "TAXON_GROUP", "PERIOD", "RECOVERY", "FULL_LIST", "FULL_DOMS", "FULL_COUNT", "WILD_DOMESTIC_STATUS", "ZONE", "REGION", "SITE_CODE", "LAT", "LONG", "TYPE")
lumped.data <- data[, j=list(NISP=sum(NISP)), by=lump.list]
lumped.data <- lumped.data[,SITE.PERIOD:=paste(SITE_CODE, PERIOD, sep=".")]

# Create list of sites for plotting
sites.for.map <- lumped.data[,j=list(NISP=sum(NISP)),by=c("SITE_CODE", "SITE", "LAT", "LONG", "PERIOD", "FULL_LIST", "FULL_DOMS", "FULL_COUNT", "RECOVERY", "ZONE", "REGION", "TYPE")]

# Filter for sample size
period.NISP <- tapply(lumped.data$NISP, lumped.data$SITE.PERIOD, FUN=sum)
valid <- row.names(period.NISP)[period.NISP>199]
lumped.data <- lumped.data[SITE.PERIOD%in%valid,]

# Apply pro rata allocation function
lumped.data <- taxa.pro.rata(lumped.data, c("susscrf", "susscrd"), "susspec", "susscrd", "SITE.PERIOD")
lumped.data <- taxa.pro.rata(lumped.data, c("bosprim", "bostaur"), "bosspec", "bostaur", "SITE.PERIOD")
lumped.data <- taxa.pro.rata(lumped.data, c("canifam", "canilup"), "canispe", "canifam", "SITE.PERIOD")

# Special case for Opovo: allocate based on DZ ratio
opovo.pigs <- lumped.data[SITE_CODE=="OPO"&TAXON=="susspec", NISP]
lumped.data <- lumped.data[SITE_CODE=="OPO" & TAXON=="susscrf", NISP:=round((opovo.pigs/442)*354)]
lumped.data <- lumped.data[SITE_CODE=="OPO" & TAXON=="susscrd", NISP:=round((opovo.pigs/442)*88)]
lumped.data <- lumped.data[!(SITE_CODE=="OPO"&TAXON=="susspec")]

##################################################################
###   Calculate key percentages                                ###
##################################################################

# Wild vs domestic ratios
wild.dom <- lumped.data[, sum(NISP), by=c("SITE_CODE", "SITE.PERIOD", "WILD_DOMESTIC_STATUS", "ZONE", "REGION", "PERIOD")]
wild.dom <- dcast.data.table(wild.dom, SITE_CODE+SITE.PERIOD+ZONE+REGION+PERIOD ~ WILD_DOMESTIC_STATUS, value.var="V1", fun=sum, fill=0)

# Frequencies of the main domesticates
doms <- lumped.data[TAXON_GROUP %in% c("bostaur", "susscrd", "oviscap", "canifam"),]
doms <- dcast.data.table(doms, SITE_CODE+SITE.PERIOD ~ TAXON_GROUP, value.var="NISP", fun=sum, fill=0)

# Merge and bring the basic site info back in
summary.data <- merge(wild.dom, doms, by=c("SITE_CODE", "SITE.PERIOD"), all=FALSE)
summary.data <- merge(sites.for.map, summary.data, by=c("SITE_CODE", "ZONE", "REGION", "PERIOD"), all=FALSE)

# Key percentages
summary.data <- summary.data[,pc.wild:=wild/(wild+domestic)*100]
summary.data <- summary.data[,pc.cattle:=bostaur/(bostaur+susscrd+oviscap)*100]
summary.data <- summary.data[,pc.pigs:=susscrd/(bostaur+susscrd+oviscap)*100]
summary.data <- summary.data[,pc.caprines:=oviscap/(bostaur+susscrd+oviscap)*100]

# Add numerical site code for map labels
summary.data <- summary.data[, SITE_NUM := as.numeric(as.factor(summary.data$SITE_CODE))]
summary.data <- summary.data[, map := c(1, diff(SITE_NUM))] #Stores variable indicating duplicates

# Merge citation info back in, concatenating where necessary
summary.data <- merge(summary.data, phases[, list(SITE_CODE, PERIOD, CITATION)], by=c("SITE_CODE", "PERIOD"))
summary.data <- data.table(summary.data, key=c("SITE_CODE", "PERIOD", "CITATION"))
summary.data <- unique(summary.data) #removes duplicate phases with the same citation
for(i in 1:(nrow(summary.data)-1)) { #concatenates citations where multiple reports merged
    if(summary.data[i, SITE_CODE] == summary.data[i+1, SITE_CODE] & summary.data[i, PERIOD] == summary.data[i+1, PERIOD]) {
        summary.data <- summary.data[i, CITATION := paste(CITATION, summary.data[i+1, CITATION], sep=", ")]
        summary.data <- summary.data[i+1, map := 9]
    }
}
summary.data <- summary.data[!map == 9] #removes remaining duplicates

##################################################################
###   Perform correspondence analysis                          ###
##################################################################

# Remove sites without full data
lumped.data <- lumped.data[FULL_COUNT==1]

# Combine small carnivores into single group for simplicity
sm.carn <- c("martspe", "mustspe", "lynxlyn", "vulpvul", "lutrlut", "felisil", "melemel")
lumped.data <- lumped.data[, CA_TAXON := TAXON_GROUP]
lumped.data <- lumped.data[TAXON_GROUP %in% sm.carn, CA_TAXON := "sm.carn"]

# Conduct CA and extract scores
##TO ADD: find variance explained and append to axis labels
table <- dcast.data.table(lumped.data[!SITE_CODE=="ODM"], SITE.PERIOD ~ CA_TAXON, value.var="NISP", fun=sum, fill=0)
phase.names <- table[, SITE.PERIOD]
table <- as.matrix(table[, SITE.PERIOD := NULL])
main.ca <- ca(table)
taxon.scores <- data.table(TAXON = main.ca[[9]], main.ca[[13]][, 1:2])
phase.scores <- data.table(SITE.PERIOD=phase.names, main.ca[[7]][, 1:2])

# Set labels for taxa
taxon.scores <- merge(taxon.scores, taxa[,list(TAXON, GENUS)], by="TAXON", all.x=TRUE, all.y=FALSE)
taxon.scores <- taxon.scores[TAXON=="bosprim", GENUS:="Bos (wild)"]
taxon.scores <- taxon.scores[TAXON=="bostaur", GENUS:="Bos (dom.)"]
taxon.scores <- taxon.scores[TAXON=="susscrf", GENUS:="Sus (wild)"]
taxon.scores <- taxon.scores[TAXON=="susscrd", GENUS:="Sus (dom.)"]
taxon.scores <- taxon.scores[TAXON=="capribe", GENUS:="Capra ibex"]
taxon.scores <- taxon.scores[TAXON=="canifam", GENUS:="Canis (dom.)"]
taxon.scores <- taxon.scores[TAXON=="canilup", GENUS:="Canis (wild)"]
taxon.scores <- taxon.scores[TAXON=="sm.carn", GENUS:="Small carnivore"]

# Merge phase information with phase loadings
phase.scores <- merge(phase.scores, summary.data[, list(PERIOD, SITE.PERIOD, RECOVERY, ZONE, REGION, TYPE)], by="SITE.PERIOD", all=FALSE)

##################################################################
###   Zoom in on dated continental Early Neolithic sites       ###
##################################################################

# Estimate ranges for dated Early Neolithic sites
EN.dates <- EN.dates[C14STD < 101, ]
EN.dates <- EN.dates[, curve := "intcal13"]
date.ranges <- ddply(EN.dates, "PHASE", chron.range)

# Select only continental Early Neolithic
EN.data <- data[PERIOD==1 & ZONE=="Continental"]

# Filter for sample size
period.NISP <- tapply(EN.data$NISP, EN.data$PHASE, FUN=sum)
valid <- row.names(period.NISP)[period.NISP>199]
EN.data <- EN.data[PHASE%in%valid,]

# Pro rata allocation
EN.data <- taxa.pro.rata(EN.data, c("susscrf", "susscrd"), "susspec", "susscrd", "PHASE")
EN.data <- taxa.pro.rata(EN.data, c("bosprim", "bostaur"), "bosspec", "bostaur", "PHASE")
EN.data <- taxa.pro.rata(EN.data, c("canifam", "canilup"), "canispe", "canifam", "PHASE")

# Wild vs domestic ratios
EN.data <- EN.data[TAXON_GROUP=="equuspe", WILD_DOMESTIC_STATUS:="wild"] # Make assumption that no domestic equids present
wild.dom <- EN.data[, sum(NISP), by=c("SITE_CODE", "PHASE", "WILD_DOMESTIC_STATUS", "REGION")]
wild.dom <- dcast.data.table(wild.dom, SITE_CODE+PHASE+REGION ~ WILD_DOMESTIC_STATUS, value.var="V1", fun=sum, fill=0)

# Frequencies of the main domesticates
doms <- EN.data[TAXON_GROUP %in% c("bostaur", "susscrd", "oviscap", "canifam"),]
doms <- dcast.data.table(doms, SITE_CODE+PHASE ~ TAXON_GROUP, value.var="NISP", fun=sum, fill=0)

# Merge and bring the date ranges in
EN.summary <- merge(wild.dom, doms, by=c("PHASE","SITE_CODE"), all=FALSE)
EN.summary <- merge(EN.summary, date.ranges, by="PHASE", all.x=TRUE, all.y=FALSE)

# Key percentages
EN.summary <- EN.summary[, pc.wild := wild/(wild+domestic)*100]
EN.summary <- EN.summary[, Cattle := bostaur/(bostaur+susscrd+oviscap)*100]
EN.summary <- EN.summary[, Pigs := susscrd/(bostaur+susscrd+oviscap)*100]
EN.summary <- EN.summary[, Caprines := oviscap/(bostaur+susscrd+oviscap)*100]

##################################################################
###   Produce summary tables (TABLES 2-4)                      ###
##################################################################

# Set up output folder if necessary
if (!file.exists("Output")) {dir.create(file.path(getwd(), "Output"))}

# Tabulate sites and NISP included in analysis - TABLE 2
summary.data <- summary.data[FULL_DOMS==1 | FULL_COUNT==1, ]
tab.2 <- summary.data[, list(SITE_NUM, SITE, ZONE, REGION, TYPE, PERIOD, NISP, CITATION)]
setnames(tab.2, "SITE_NUM", "NO.")
write.csv(tab.2, file.path("Output", "Table2.csv"), row.names=FALSE)

# Tabulate by period and region - TABLE 3
tab.3 <- with(summary.data, ftable(ZONE, TYPE, PERIOD))
write.csv(tab.3, file.path("Output", "Table3data.csv"), row.names=FALSE)

# Tabulate by period, region, and recovery group - TABLE 4
tab.4 <- with(summary.data, ftable(ZONE, PERIOD, RECOVERY))
write.csv(tab.4, file.path("Output", "Table4data.csv"), row.names=FALSE)

##################################################################
###   Plotting map of site locations (FIGURE 1)                ###
##################################################################

col.codes <- col.codes[order(order)]
type.symbols = c(24,21)
leg.cols <- rgb(col.codes$red, col.codes$green, col.codes$blue, col.codes$alpha, names=col.codes$Region, maxColorValue = 255)
summary.data <- merge(summary.data, lab.nudge, by="SITE_NUM")

tiff(file = file.path("Output", "Figure1.tiff"), width=5600, height=3380, res=600)
    par(mar=c(2,2,0.5,0))
    plot(map.data, col=grey.colors(100), cex.axis=0.7, xlim=c(13, 25), ylim=c(41, 46.5), colNA="skyblue", legend=FALSE)
    plot(lakes, col="skyblue", border=NA, add=TRUE)
    plot(rivers, col="skyblue", lwd=0.3, add=TRUE)
    plot(gadm.list[[1]], lwd=0.5, add=TRUE)
    plot(gadm.list[[2]], lwd=0.5, border="grey35", add=TRUE)
    for(i in 3:length(gadm.list)) {
        plot(gadm.list[[i]], lwd=0.5, add=TRUE)
    }
    with(summary.data, points(LONG, LAT, pch=type.symbols[TYPE], cex=1, lwd=1.2, bg=cols[REGION]))
    with(summary.data[map==1], text(LONG + X/10, LAT + Y/10, SITE_NUM, cex=0.7, font=2))
    scalebar(200, c(16.4, 41.3), "bar", 4)
    legend("bottomleft", legend=col.codes$REGION, pt.bg=leg.cols, pt.lwd=1.2, cex=0.8, pt.cex=1.2, pch=21, bg=rgb(1,1,1,0.65))
dev.off()

##################################################################
###   Plot beeswarms by region and period (FIGURE 2)           ###
##################################################################

# Prepare for plotting summary data
period.labs <- c("1" = "Early", "2" = "Middle", "3" = "Late")
metric.list <- c("Caprines", "Cattle", "Pigs")
metric.labs <- cbind(c("% wild", "% caprines", "% cattle", "% pigs"), "", "")
setnames(summary.data, c("pc.caprines", "pc.cattle", "pc.pigs"), metric.list)

# And plot it
tiff(file = file.path("Output", "Figure2.tiff"), width=750, height=850, pointsize = 15)
    par(mfrow=c(4,3), mar=c(1.6, 1.6, 1.6, 1.6), oma=c(1, 3.5, 1.5, 0), xpd=NA)
    for(i in 1:3) {
        NISPswarm(summary.data[PERIOD==i & FULL_COUNT==1], "pc.wild", metric.labs[1, i], period.labs[i], cols, "REGION")
    }
    for(j in 1:3) {
        for(k in 1:3) {
            NISPswarm(summary.data[PERIOD==k & FULL_DOMS==1], metric.list[j], metric.labs[j+1, k], NULL, cols, "REGION")
        }
    }
dev.off()
    
##################################################################
###   Plot summary data on map (FIGURE 3)                      ###
##################################################################

# Prepare to plot summary data on map
bwPal <- colorRampPalette(c("white", "black"))
bw.breaks <- 5
summary.data <- summary.data[, wild.col := bwPal(bw.breaks)[as.numeric(cut(pc.wild, breaks = bw.breaks))]]
bw.labs <- paste(as.character(seq(from=0, length.out=bw.breaks,by=(100/bw.breaks))), "-", as.character(seq(from=(100/bw.breaks), length.out=bw.breaks,by=(100/bw.breaks))), "%", sep="")
long.data <- melt.data.table(summary.data, c("LAT", "LONG", "PERIOD", "SITE_CODE", "X_1", "Y_1"), c("Pigs", "Caprines", "Cattle"), "TAXON", "NISP")
pie.data <- list()
for(i in 1:3) {
    pie.data[[i]] <- with(long.data[PERIOD==i], make.xyz(LONG + X_1/10, LAT + Y_1/10, NISP, TAXON))
}
axis.list <- c("n", "n", "s")
pane.lab <- c("Early", "Middle", "Late")

# And actually plot it
tiff(file = file.path("Output", "Figure3.tiff"), width=3000, height=5060, res=400)
    par(mfrow=c(3,1), mar=c(0,2,0.5,0), oma=c(2,0,0,0))
    for(i in 1:3) {
        plot(map.data, col=grey.colors(100), cex.axis=0.7, xlim=c(13, 25), ylim=c(41, 46.5), colNA="skyblue", legend=FALSE, xaxt=axis.list[i], cex.axis=1.1)
        plot(lakes, col="skyblue", border=NA, add=TRUE)
        plot(rivers, col="skyblue", lwd=0.3, add=TRUE)
        plot(gadm.list[[1]], lwd=0.5, add=TRUE)
        plot(gadm.list[[2]], lwd=0.5, border="grey35", add=TRUE)
        for(j in 3:length(gadm.list)) {
            plot(gadm.list[[j]], lwd=0.5, add=TRUE)
        }
        with(summary.data[PERIOD==i], points(LONG, LAT, pch=type.symbols[TYPE], cex=c(2.5,3.3)[TYPE], bg=wild.col))
        with(pie.data[[i]], draw.pie(x, y, z, 0.11, scale=FALSE,
                        col=c("darkblue", "darkgreen", "darkred")))
        legend(x=13.7, y=46.5, legend=pane.lab[i], text.font=2, cex=1.6, bty="n")
    }
    scalebar(200, c(16.4, 41.3), "bar", 4)
    legend("bottomleft", legend=c("Pigs", "Caprines", "Cattle"), fill=c("darkblue", "darkgreen", "darkred"), bg=rgb(1,1,1,0.65), cex=1.3, title=expression(bold("Domesticates")))
    legend("bottomright", legend=bw.labs, fill=bwPal(bw.breaks), , bg=rgb(1,1,1,0.65), cex=1.3, title=expression(bold("Wild taxa")))
dev.off()

##################################################################
###   Plot ternaries graphs by region and period (FIGURE 4)    ###
##################################################################

# Pre-set theme for ternary plots
tern.style <- list(aes(x = Pigs, y = Cattle, z = Caprines),
                   scale_shape_manual(values = c(24,21)),
                   theme_rgbw(),
                   theme_showarrows(),
                   Rlab("O/C", labelarrow = "Caprines"),
                   Wlab("%"),
                   theme(strip.text = element_text(size=12)),
                   theme(legend.position=0))

# Set up ternary plots
p <- ggtern(data = summary.data) + tern.style +
  geom_point(aes(fill = REGION, shape = TYPE), size=2) +
  facet_grid(.~PERIOD, labeller=labeller(PERIOD = period.labs)) +
  scale_fill_manual(values = cols)

# Plot them
tiff(file = file.path("Output", "Figure4.tiff"), width=4500, height=1400, res=400)
  p
dev.off()


##################################################################
###   Plot correspondence analysis results (FIGURE 5)          ###
##################################################################

# Set up plot, labels, etc.
xlims <- c(min(taxon.scores$Dim1, phase.scores$Dim1)-0.1, max(taxon.scores$Dim1, phase.scores$Dim1)+0.1)
ylims <- c(min(taxon.scores$Dim2, phase.scores$Dim2)-0.1, max(taxon.scores$Dim2, phase.scores$Dim2)+0.1)

major.taxa <- c("Ovis/Capra", "Sus (dom.)", "Sus (wild)", "Bos (dom.)", "Cervus", "Capreolus")
black <- as.numeric(taxon.scores$GENUS %in% major.taxa) +1
label.pos <- c(2, 3, 2, 2, 1, 4, 4, 1, 3, 2, 2, 2, 3, 1, 2, 3, 3) # manually set label positions
bi.col <- c("gray52", "black")
col.codes <- col.codes[order(order)]
legend.cols <- rgb(col.codes$red, col.codes$green, col.codes$blue, col.codes$alpha, names=col.codes$Region, maxColorValue = 255)

# Plot it
tiff(file = file.path("Output", "Figure5.tiff"), width=3280, height=3200, res=400)
    par(mfrow=c(2,2), pty="s", mar=c(4, 3, 1, 0.6), xpd=FALSE)
    
    # Pane a
    plot(main.ca, xlim=xlims, ylim=ylims, what="none", xlab="", cex.axis=0.9)
    with(taxon.scores, points(Dim1, Dim2, pch=4, col=bi.col[black]))
    with(taxon.scores, text(Dim1, Dim2, labels=GENUS, cex=0.9, col=bi.col[black], font=3, pos=label.pos))
    legend("topleft", legend="A.", cex=1.1, bty="n")
    
    # Panes b-d
    plot(main.ca, xlim=xlims, ylim=ylims, what="none", xlab="", ylab="", cex.axis=0.9)
    with(taxon.scores, points(Dim1, Dim2, pch=4, col=bi.col[black]))
    with(phase.scores[PERIOD==1], points(Dim1, Dim2, pch=type.symbols[TYPE], cex=1.2, bg=cols[REGION]))
    legend("topleft", legend="B. c.6100-5500 cal BC", cex=1.1, bty="n")
    
    plot(main.ca, xlim=xlims, ylim=ylims, what="none", cex.axis=0.9)
    with(taxon.scores, points(Dim1, Dim2, pch=4, col=bi.col[black]))
    with(phase.scores[PERIOD==2], points(Dim1, Dim2, pch=type.symbols[TYPE], cex=1.2, bg=cols[REGION]))
    legend("topleft", legend="C. c.5500-5000 cal BC", cex=1.1, bty="n")
    legend("bottomleft", pch=21, cex=0.88, pt.bg=legend.cols, legend=col.codes$REGION, bty="n")
    
    plot(main.ca, xlim=xlims, ylim=ylims, what="none", ylab="", cex.axis=0.9)
    with(taxon.scores, points(Dim1, Dim2, pch=4, col=bi.col[black]))
    with(phase.scores[PERIOD==3], points(Dim1, Dim2, pch=type.symbols[TYPE], cex=1.2, bg=cols[REGION]))
    legend("topleft", legend="D. c.5000-4500 cal BC", cex=1.1, bty="n")
dev.off()

##################################################################
###   Plot metrics against log(NISP) (FIGURE 6)                ###
##################################################################

r.wild.Adr <- with(summary.data[ZONE=="Adriatic",], cor.test(log(NISP), pc.wild))
r.wild.Con <- with(summary.data[ZONE=="Continental",], cor.test(log(NISP), pc.wild))

r.cattle.Adr <- with(summary.data[ZONE=="Adriatic",], cor.test(log(NISP), Cattle))
r.cattle.Con <- with(summary.data[ZONE=="Continental",], cor.test(log(NISP), Cattle))

r.caprines.Adr <- with(summary.data[ZONE=="Adriatic",], cor.test(log(NISP), Caprines))
r.caprines.Con <- with(summary.data[ZONE=="Continental",], cor.test(log(NISP), Caprines))

tiff(file = file.path("Output", "Figure6.tiff"), width=2400, height=3000, res = 400)
      par(mfrow=c(3,2), mar=c(1,1,1,1), oma=c(4,4,0,0), xpd=NA)

      with(summary.data[ZONE=="Adriatic",], plot(log(NISP), pc.wild, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], xaxt="n", xlab="", ylab="%wild"))
      legend("topright", cex=1.5, legend="Adriatic", bty="n")
      legend("bottomright", legend=paste0("r=", sprintf("%.3f", round(r.wild.Adr[[4]], 3)), "; p=", sprintf("%.3f", round(r.wild.Adr[[3]], 3))), bty="n")
      par(xpd=FALSE)
      with(summary.data[ZONE=="Adriatic",], abline(lm(pc.wild ~ log(NISP))))

      with(summary.data[ZONE=="Continental",], plot(log(NISP), pc.wild, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], xaxt="n", yaxt="n", xlab="", ylab=""))
      legend("topright", cex=1.5, legend="Continental", bty="n")
      legend("topleft", legend=paste0("r=", sprintf("%.3f", round(r.wild.Con[[4]], 3)), "; p=", sprintf("%.3f", round(r.wild.Con[[3]], 3))), bty="n")
      with(summary.data[ZONE=="Continental",], abline(lm(pc.wild ~ log(NISP))))

      par(xpd=NA)
      with(summary.data[ZONE=="Adriatic",], plot(log(NISP), Cattle, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], xaxt="n", xlab="", ylab="%cattle"))
      legend("topright", legend=paste0("r=", sprintf("%.3f", round(r.cattle.Adr[[4]], 3)), "; p=", sprintf("%.3f", round(r.cattle.Adr[[3]], 3))), bty="n")
      par(xpd=FALSE)
      with(summary.data[ZONE=="Adriatic",], abline(lm(Cattle ~ log(NISP))))

      with(summary.data[ZONE=="Continental",], plot(log(NISP), Cattle, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], xaxt="n", yaxt="n", xlab="", ylab=""))
      legend("bottomright", legend=paste0("r=", sprintf("%.3f", round(r.cattle.Con[[4]], 3)), "; p=", sprintf("%.3f", round(r.cattle.Con[[3]], 3))), bty="n")
      with(summary.data[ZONE=="Continental",], abline(lm(Cattle ~ log(NISP))))

      par(xpd=NA)
      with(summary.data[ZONE=="Adriatic",], plot(log(NISP), Caprines, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], ylab="%caprines"))
      legend("bottomright", legend=paste0("r=", sprintf("%.3f", round(r.caprines.Adr[[4]], 3)), "; p=", sprintf("%.3f", round(r.caprines.Adr[[3]], 3))), bty="n")
      par(xpd=FALSE)
      with(summary.data[ZONE=="Adriatic",], abline(lm(Caprines ~ log(NISP))))

      par(xpd=NA)
      with(summary.data[ZONE=="Continental",], plot(log(NISP), Caprines, xlim=c(5.2, 10.5), ylim=c(0,100), cex=1.5, cex.axis=1.5, cex.lab=1.8, pch=type.symbols[TYPE], bg=cols[REGION], ylab="", yaxt="n"))
      legend("topright", legend=paste0("r=", sprintf("%.3f", round(r.caprines.Con[[4]], 3)), "; p=", sprintf("%.3f", round(r.caprines.Con[[3]], 3))), bty="n")
      par(xpd=FALSE)
      with(summary.data[ZONE=="Continental",], abline(lm(Caprines ~ log(NISP))))
dev.off()


##################################################################
###   Plot summary beeswarms by recovery (FIGURE 7)            ###
##################################################################

# Prepare data for plotting by recovery
sieve.cols = c("red", "orange", "yellow", "green", "white")

# Plot beeswarms
tiff(file = file.path("Output", "Figure7.tiff"), width=750, height=850, pointsize = 15)
    par(mfrow=c(4,3), mar=c(1.6, 1.6, 1.6, 1.6), oma=c(1, 3.5, 1.5, 0), xpd=NA)
    for(i in 1:3) {
        NISPswarm(summary.data[PERIOD==i & FULL_COUNT==1], "pc.wild", metric.labs[1, i], period.labs[i], sieve.cols, "RECOVERY")
    }
    for(j in 1:3) {
        for(k in 1:3) {
            NISPswarm(summary.data[PERIOD==k & FULL_DOMS==1], metric.list[j], metric.labs[j+1, k], NULL, sieve.cols, "RECOVERY")
            if(j==3 & k==1) {
                legend("topleft", pch=21, pt.bg=sieve.cols, legend=c("No sieving", "Limited sieving", "Frequent sieving", "100% sieved", "Unknown"))
            }
        }
    }
dev.off()

##################################################################
###   Plot ternary graph by recovery (FIGURE 8a)               ###
##################################################################

# Set up ternary plot
q <- ggtern(data = summary.data) + tern.style +
    geom_point(aes(fill = RECOVERY, shape = TYPE), size=2) +
    scale_fill_manual(values = c("red", "orange", "yellow", "green", "white"))

# Plot it
tiff(file = file.path("Output", "Figure8a.tiff"), width=2000, height=1800, res=400)
    q
dev.off()
  
##################################################################
###   Plot correspondence analysis by recovery (FIGURE 8b)     ###
##################################################################

tiff(file = file.path("Output", "Figure8b.tiff"), width=2400, height=2400, res=400)
    par(mfrow=c(1,1), pty="s", xpd=NA, mar=c(4,3,2,1))
    with(taxon.scores, plot(Dim1, Dim2, pch=4, xlab="Dimension 1", ylab="Dimension 2", col=bi.col[black], xlim=xlims, ylim=ylims, cex.lab=0.9, cex.axis=0.9))
    with(taxon.scores, text(Dim1, Dim2, labels=GENUS, cex=1, col=bi.col[black], font=3, pos=label.pos))
    with(phase.scores, points(Dim1, Dim2, pch=type.symbols[TYPE], cex=1.2, bg=sieve.cols[RECOVERY]))
    legend("bottomleft", pch=21, pt.bg=sieve.cols, legend=c("No sieving", "Limited sieving", "Frequent sieving", "100% sieved", "Unknown"))
dev.off()

##################################################################
###   Plot metrics for dated continental EN sites (FIGURE 9)   ###
##################################################################

bar.cols <- cols
bar.cols[bar.cols=="#FFFFFFFF"] <- "grey"

tiff(file = file.path("Output", "Figure9.tiff"), width=2000, height=2400, res=400)
    par(mfrow=c(4,1), mar=c(0,4,1,1), oma=c(5,0,0,0))
    with(EN.summary, plot(V2, pc.wild, type = "n", xlim = c(6200, 5500), ylim = c(0, 100), ylab = "%wild", xaxt = "n"))
    with(EN.summary, arrows(V1, pc.wild, V3, pc.wild, length=0.00, code=3, lwd=1, col=bar.cols[REGION]))
    with(EN.summary, points(V2, pc.wild, pch = 21, cex=1.2, col = "black", lwd = 1, bg = cols[REGION]))

    with(EN.summary, plot(V2, Caprines, type = "n", xlim = c(6200, 5500), ylim = c(0, 100), ylab = "%caprines", xaxt = "n"))
    with(EN.summary, arrows(V1, Caprines, V3, Caprines, length=0.00, code=3, lwd=1, col=bar.cols[REGION]))
    with(EN.summary, points(V2, Caprines, pch = 21, cex=1.2, col = "black", lwd = 1, bg = cols[REGION]))
    
    with(EN.summary, plot(V2, Cattle, type = "n", xlim = c(6200, 5500), ylim = c(0, 100), ylab = "%cattle", xaxt = "n"))
    with(EN.summary, arrows(V1, Cattle, V3, Cattle, length=0.00, code=3, lwd=1, col=bar.cols[REGION]))
    with(EN.summary, points(V2, Cattle, pch = 21, cex=1.2, col = "black", lwd = 1, bg = cols[REGION]))

    with(EN.summary, plot(V2, Pigs, type = "n", xlim = c(6200, 5500), ylim = c(0, 100), ylab = "%pigs"))
    with(EN.summary, arrows(V1, Pigs, V3, Pigs, length=0.00, code=3, lwd=1, col=bar.cols[REGION]))
    with(EN.summary, points(V2, Pigs, pch = 21, cex=1.2, col = "black", lwd = 1, bg = cols[REGION]))

    title(xlab = "Years cal. BC", outer = TRUE)
dev.off()


